@@ -148,6 +148,18 @@ class Gates:
                            [0, 1 / sqrt(2), I / sqrt(2), 0],
                            [0, I / sqrt(2), 1 / sqrt(2), 0],
                            [0, 0, 0, 1]])
+        
+    def Gamma():
+        if Mode.representation == 'numpy':
+            return 1/2 * np.array([[1, -1, 1, -1], 
+                                   [1, 1, -1, -1], 
+                                   [1, -1, -1, 1], 
+                                   [1, 1, 1, 1]])
+        else:
+            return 1/2 * Matrix([[1, -1, 1, -1], 
+                                 [1, 1, -1, -1], 
+                                 [1, -1, -1, 1], 
+                                 [1, 1, 1, 1]])
 
     def Magic():
         if Mode.representation == 'numpy':
@@ -196,3 +208,15 @@ class Gates:
                            [0, exp(I * theta / 2), 0, 0],
                            [0, 0, exp(I * theta / 2), 0],
                            [0, 0, 0, exp(-I * theta / 2)]])
+        
+    def CAN(tx:float, ty:float, tz:float):
+        if Mode.representation == 'numpy':
+            return np.array([[np.exp(-1j*tz/2)*np.cos((tx-ty)/2), 0, 0, -1j*np.exp(-1j*tz/2)*np.sin((tx-ty)/2)], 
+                             [0, np.exp(1j*tz/2)*np.cos((tx+ty)/2), -1j*np.exp(1j*tz/2)*np.sin((tx+ty)/2), 0], 
+                             [0, -1j*np.exp(1j*tz/2)*np.sin((tx+ty)/2), np.exp(1j*tz/2)*np.cos((tx+ty)/2), 0], 
+                             [-1j*np.exp(-1j*tz/2)*np.sin((tx-ty)/2), 0, 0, np.exp(-1j*tz/2)*np.cos((tx-ty)/2)]])
+        else:
+            return Matrix([[exp(-I*tz/2)*cos((tx-ty)/2), 0, 0, -I*exp(-I*tz/2)*sin((tx-ty)/2)], 
+                           [0, exp(I*tz/2)*cos((tx+ty)/2), -I*exp(I*tz/2)*sin((tx+ty)/2), 0], 
+                           [0, -I*exp(I*tz/2)*sin((tx+ty)/2), exp(I*tz/2)*cos((tx+ty)/2), 0], 
+                           [-I*exp(-I*tz/2)*sin((tx-ty)/2), 0, 0, exp(-I*tz/2)*cos((tx-ty)/2)]])
